@@ -7,7 +7,7 @@ def document_view(request, *args, **kwargs):
     if kwargs.get('current_page', False):
         documents = Document.objects.filter(page=kwargs['current_page'])
         context['documents'] = documents
-    if kwargs.has_key('document_id'):
+    if 'document_id' in kwargs:
         document = Document.objects.get(pk=int(kwargs['document_id']))
         context['document'] = document
     context['in_document_view'] = True
